==> pulseaudio-0.9.15-i486-6gsb.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libpulse-simple.so.0 )
( cd usr/lib ; ln -sf libpulse-simple.so.0.0.2 libpulse-simple.so.0 )
( cd usr/lib ; rm -rf libpulse-mainloop-glib.so )
( cd usr/lib ; ln -sf libpulse-mainloop-glib.so.0.0.4 libpulse-mainloop-glib.so )
( cd usr/lib ; rm -rf libpulse.so.0 )
( cd usr/lib ; ln -sf libpulse.so.0.8.0 libpulse.so.0 )
( cd usr/lib ; rm -rf libpulse-mainloop-glib.so.0 )
( cd usr/lib ; ln -sf libpulse-mainloop-glib.so.0.0.4 libpulse-mainloop-glib.so.0 )
( cd usr/lib ; rm -rf libpulse.so )
( cd usr/lib ; ln -sf libpulse.so.0.8.0 libpulse.so )
( cd usr/lib ; rm -rf libpulse-simple.so )
( cd usr/lib ; ln -sf libpulse-simple.so.0.0.2 libpulse-simple.so )
( cd usr/lib ; rm -rf libltdl.so.7 )
( cd usr/lib ; ln -sf libltdl.so.7.2.0 libltdl.so.7 )
( cd usr/lib ; rm -rf libpulse-browse.so.0 )
( cd usr/lib ; ln -sf libpulse-browse.so.0.1.1 libpulse-browse.so.0 )
( cd usr/lib ; rm -rf libpulse-browse.so )
( cd usr/lib ; ln -sf libpulse-browse.so.0.1.1 libpulse-browse.so )
( cd usr/bin ; rm -rf parec )
( cd usr/bin ; ln -sf pacat parec )

# Preserve new configuration files
install_file() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

install_file etc/pulse/daemon.conf.new
install_file etc/pulse/client.conf.new
install_file etc/pulse/default.pa.new
install_file etc/pulse/system.pa.new

# If the pulse group doesn't exist, add it
# pulse is required for user level 
if ! grep "^pulse:" etc/group >/dev/null 2>&1; then
  echo "pulse:x:53:" >>etc/group
fi
if ! grep "^pulse:" etc/passwd >/dev/null 2>&1; then
  echo "pulse:x:53:53:pulse:/var/run/pulse:/bin/false" >>etc/passwd
fi
if ! grep "^pulse:" etc/gshadow >/dev/null 2>&1; then
  echo "pulse:*::" >>etc/gshadow
fi
if ! grep "^pulse:" etc/shadow >/dev/null 2>&1; then
  echo "pulse:*:9797:0:::::" >>etc/shadow 
fi

# If the pulse, pulse-access and pulse-rt groups don't exist, add them
# pulse-rt and pulse-access required for system-wide daemon
# disabled per default
#if ! grep "^pulse-access:" etc/group >/dev/null 2>&1; then
  #echo "pulse-access:x:54:" >>etc/group
#fi
#if ! grep "^pulse-access:" etc/gshadow >/dev/null 2>&1; then
  #echo "pulse-access:*::" >>etc/gshadow
#fi
#if ! grep "^pulse-rt:" etc/group >/dev/null 2>&1; then
  #echo "pulse-rt:x:55:" >>etc/group
#fi
#if ! grep "^pulse-rt:" etc/gshadow >/dev/null 2>&1; then
  #echo "pulse-rt:*::" >>etc/gshadow
#fi

# If pulseaudio installed, prefer is to esd
if [ -f usr/bin/esdcompat ]; then
  # Move old esd out of the way
  if [ -f usr/bin/esd -a ! -f usr/bin/esound.pulsified ]; then
    chroot . mv -f usr/bin/esd usr/bin/esound.pulsified ;
  fi;
  # Make sure pulseaudio is default instead of esd
  chroot . ln -sf /usr/bin/esdcompat usr/bin/esd ;
fi; 

# If pulseaudio installed, prefer is to paplay
if [ -f usr/bin/paplay ]; then
  # Move old esdplay out of the way
  if [ -f usr/bin/esdplay -a ! -f usr/bin/esdplay.pulsified ]; then
    chroot . mv -f usr/bin/esdplay usr/bin/esdplay.pulsified ;
  fi ;
  # Make sure paplay is default instead of esdplay
  chroot . ln -sf /usr/bin/paplay usr/bin/esdplay ;
fi;

==> pulseaudio-0.9.22-i486-3gsb.txz: install/doinst.sh <==
( cd usr/bin ; rm -rf parec )
( cd usr/bin ; ln -sf pacat parec )
( cd usr/bin ; rm -rf parecord )
( cd usr/bin ; ln -sf pacat parecord )
( cd usr/bin ; rm -rf pamon )
( cd usr/bin ; ln -sf pacat pamon )
( cd usr/bin ; rm -rf paplay )
( cd usr/bin ; ln -sf pacat paplay )
( cd usr/lib ; rm -rf libpulse-browse.so.0 )
( cd usr/lib ; ln -sf libpulse-browse.so.0.1.1 libpulse-browse.so.0 )
( cd usr/lib ; rm -rf libpulse-mainloop-glib.so.0 )
( cd usr/lib ; ln -sf libpulse-mainloop-glib.so.0.0.4 libpulse-mainloop-glib.so.0 )
( cd usr/lib ; rm -rf libpulse-simple.so )
( cd usr/lib ; ln -sf libpulse-simple.so.0.0.3 libpulse-simple.so )
( cd usr/lib ; rm -rf libpulse.so.0 )
( cd usr/lib ; ln -sf libpulse.so.0.12.3 libpulse.so.0 )
( cd usr/lib ; rm -rf libpulse-browse.so )
( cd usr/lib ; ln -sf libpulse-browse.so.0.1.1 libpulse-browse.so )
( cd usr/lib ; rm -rf libpulse.so )
( cd usr/lib ; ln -sf libpulse.so.0.12.3 libpulse.so )
( cd usr/lib ; rm -rf libpulse-mainloop-glib.so )
( cd usr/lib ; ln -sf libpulse-mainloop-glib.so.0.0.4 libpulse-mainloop-glib.so )
( cd usr/lib ; rm -rf libpulse-simple.so.0 )
( cd usr/lib ; ln -sf libpulse-simple.so.0.0.3 libpulse-simple.so.0 )

# Preserve new configuration files
install_file() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

install_file etc/pulse/daemon.conf.new
install_file etc/pulse/client.conf.new

# pulse group is required for user level 
if ! grep "^pulse:" etc/group >/dev/null 2>&1; then
  groupadd -g 53 pulse >/dev/null 2>&1
fi
if ! grep "^pulse:" etc/passwd >/dev/null 2>&1; then
  useradd -u 53 -g pulse -d /dev/null -s /bin/false pulse >/dev/null 2>&1
fi
